<?php
/**
 *	CLASS: Share Your Cart CubeCart Plugin
 *	AUTHOR: Barandi Solutions
 *	COUNTRY: Romania
 *	EMAIL: vlad.barliba@barandisolutions.ro
 *	VERSION : 1.0
 *	DESCRIPTION: This class is used as a base class for every wordpress shopping cart plugin we create.
 * *    Copyright (C) 2011 Barandi Solutions
 */

require_once("sdk/class.shareyourcart-base.php");

if(!class_exists('ShareYourCartCubeCartPlugin',false)){

class ShareYourCartCubeCartPlugin extends ShareYourCartBase {

	protected $_PLUGIN_PATH;
	public $adminFix = true;

	/**
	 * Constructor
	 * @param null
	 */
	function __construct() {
		parent::__construct();
	}

	/**
	 *
	 * Return the project's URL
	 *
	 */
	protected function getDomain(){
		return $GLOBALS['config']->get('config','standard_url');
	}

	/**
	 *
	 * Return the admin's email
	 *
	 */
	protected function getAdminEmail(){
		return $GLOBALS['config']->get('config','email_address');
	}

	/**
	 *
	 * Set the field value
	 *
	 */
	protected function setConfigValue($field,$value){
		$GLOBALS['config']->set('ShareYourCartConfig',$field,$value);
	}

	/**
	 *
	 * Get the field value
	 *
	 */
	protected function getConfigValue($field){
		return $GLOBALS['config']->get('ShareYourCartConfig',$field);
	}

	/**
	 *
	 * Execute the SQL statement
	 *
	 */
	protected function executeNonQuery($sql){
		$GLOBALS['db']->query($sql);
	}

	/**
	 *
	 * Based on the token, get the session_id
	 *
	 */
	protected function getSessionId($token) {

		$result = $this->getRow("SELECT session_id FROM " . $GLOBALS['config']->get('config','dbprefix').$this->getTableName('shareyourcart_tokens') . " WHERE token='$token'");

		return isset($result) ? $result['session_id'] : null;
	}

	/**
	 *
	 * Get the row returned from the SQL
	 *
	 * @return an associative array containing the data of the row OR NULL
	 *         if there is none
	 */
	protected function getRow($sql){
		$result = $GLOBALS['db']->query($sql);
		return (count($result)>0 ? $result[0]:array());
	}

	/**
	 *
	 * Rewrite original function in order to change the table name
	 */
	protected function createTable($tableName, $columns, $primaryKey, $options=NULL)
	{
		parent::createTable($GLOBALS['config']->get('config','dbprefix').$tableName, $columns, $primaryKey);
	}

	/**
	 *
	 * Get the table name based on the key
	 *
	 */
	protected function getTableName($key){
		return $key;
	}

	/**
	 *
	 * Insert the row into the specified table
	 *
	 */
	protected function insertRow($tableName,$data){
		$GLOBALS['db']->insert($tableName,$data);
	}

	/**
	 *
	 * Create url for the specified file. The file must be specified in relative path
	 * to the base of the plugin
	 */
	protected function createUrl($file){
		//get the real file path
		$file = realpath($file);

		//calculate the relative path from this file
		$file = relativepath(dirname(__FILE__),$file);
		$subject = $GLOBALS['storeURL'].'/modules/plugins/ShareYourCart/'.$file;
		return preg_replace('/\\\\/', '/', $subject);
	}

	/**
	 *
	 * This is the activate hook called by WordPress. It is used for both install and activate
	 *
	 */
	public function activateHook() {
		$message = '';

		//the db version is old, so install it again
		if(version_compare($this->getConfigValue('db_version'),self::$_DB_VERSION)!=0){
			$this->install($message);
		} else { //if the version are equal, simply activate the plugin

			$this->activate($message);
		}

		//TODO: perhaps we can show the message somehow to the user. For now, just log it
		error_log($message);
	}

	/**
	 *
	 * This is the deactivate hook called by WordPress.
	 *
	 */
	public function deactivateHook() {
		$message = '';

		$this->deactivate($message);

		//TODO: perhaps we can show the message somehow to the user. For now, just log it
		error_log($message);
	}

	/**
	 *
	 * When installing the new wordpress plugin, make sure to move the old data
	 *
	 */
	public function install(&$message = null) {
		parent::install($message);
	}

	/**
	 *
	 * This is the deactivate hook called by WordPress.
	 *
	 */
	public static function uninstallHook() {
		$message = '';

		$this->deactivate($message);

		//TODO: perhaps we can show the message somehow to the user. For now, just log it
		error_log($message);
	}

	/*
	 *
	 * Called when a new coupon is generated
	 *
	 */
	public function couponCallback(){

		if(!$this->isActive()) {

			header("HTTP/1.0 403");

			echo "Shopping Cart is not active";

			exit;
		}

		parent::couponCallback();

		//since this is actually an API, exit
		exit;
	}

	public function getButtonCallbackURL()
	{
		$callback_url = $GLOBALS['config']->get('config','standard_url').'?_g=remote&mod_type=gateway&module=ShareYourCart&action=buttonCallback';
		$product_id = (int)$_GET['product_id'];

		if(isset($_GET['product_id']) && is_numeric($product_id))
		{
			$callback_url .= '&product_id='. $product_id;
		}

		return $callback_url;
	}

	public function loadSessionData()
	{
		$GLOBALS['cart']->load();
	}

	public function getSecretKey()	{
		return '5743e51d-59a5-4f8f-a4d9-a987953cf7c2';
	}

	/**
	 *
	 * 	 Insert coupon in database
	 *
	 */
	protected function saveCoupon($token, $coupon_code, $coupon_value, $coupon_type) {

		$record		= array(
		#	'status'		=> (isset($_POST['coupon']['status'])) ? 1 : 0,
		#	'archived'		=> (isset($_POST['coupon']['archived'])) ? 1 : 0,
		'code'			=> $coupon_code,
		'product_id'	=> null,
		'expires'		=> date('Y-m-d', strtotime("now +1 day")),
		'allowed_uses'	=> 1,
		'min_subtotal'	=> '',
		''		=> 0,
		'description'	=> $coupon_value,		
		);

		switch($coupon_type)
		{
			case 'amount':
				$record['discount_price'] = $coupon_value;
				$record['shipping'] = 0;
				break;
			case 'percent':
				$record['discount_percent'] = $coupon_value;
				$record['shipping'] = 0;
				break;
			case 'free_shipping' :
				$record['discount_percent'] = 100;
				$record['shipping'] = 1;
				break;
			default :
				$record['discount_price'] = $coupon_value;
				$record['shipping'] = 0;
				break;
		}

		$GLOBALS['db']->insert('CubeCart_coupons', $record);

		//call the base class method
		parent::saveCoupon($token, $coupon_code, $coupon_value, $coupon_type);
	}

	public function applyCoupon($coupon_code){
		$GLOBALS['cart']->discountAdd($coupon_code);
		$GLOBALS['cart']->save();
	}

	public function buttonCallback(){

		if(!$this->isActive()) return;

		$callback_url = $GLOBALS['config']->get('config','standard_url').'?_g=remote&mod_type=gateway&module=ShareYourCart&action=couponCallback';
		$shopping_cart_url = $GLOBALS['config']->get('config','standard_url').'index.php?_a=basket';

		//specify the parameters
		$params = array(
			'callback_url' => $callback_url,
			'success_url' => $shopping_cart_url,
			'cancel_url' => $shopping_cart_url,
		);

		//there is no product set, thus send the products from the shopping cart
		if(!isset($_REQUEST['product_id']))
		{
			//add the cart items to the arguments
			foreach($GLOBALS['cart']->get() as $product)
			{
				$params['cart'][] = array(
				"item_name" => $product['name'],
				"item_url" => '',
				"item_price" => $product['sale_price'],
				"item_description" => $product['description'], 
				"item_picture_url" => '',
				);
			} //cart loop
		}
		else
		{
			$product_id = (int)$_REQUEST['product_id'];
			$product = $GLOBALS['catalogue']->getProductData($product_id);

			$params['cart'][] = array(
				"item_name" => $product['name'],
				"item_url" => '',
				"item_price" => $product['sale_price'],
				"item_description" => $product['description'], 
				"item_picture_url" => '',
			);
		}

		try
		{
			$this->startSession($params);
		}
		catch(Exception $e)
		{
			//display the error to the user
			echo $e->getMessage();
		}
		exit;

	}
	
	public function isSingleProduct()
	{
		return true;
	}
}

} //END IF
?>